# -*- coding: utf-8 -*-
"""
SOLEIL synchrotron parameters script.

@author: Alexis Gamelin
@date: 14/01/2020
"""

import numpy as np
from Tracking.synchrotron import Synchrotron, Electron, Optics
from Tracking.beam import Beam

def soleil(mode = 'Uniform'):
    """
    
    """
    
    h = 416
    L = 3.540969742590899e+02
    E0 = 2.75e9
    particle = Electron()
    ac = 4.16e-4
    U0 = 1171e3
    tau = np.array([0, 0, 3.27e-3])
    tune = np.array([18.15687, 10.22824, 0.00502])
    emit = np.array([4.5e-9, 4.5e-9*0.01])
    sigma_0 = 8e-12
    sigma_delta = 9e-4
    
    # mean values
    beta = np.array([3, 1.3])
    alpha = np.array([0, 0])
    mean_val = Optics(beta, alpha)
    
    ring = Synchrotron(h, L, E0, particle, ac=ac, U0=U0, tau=tau,
                       mean_optics=mean_val, emit=emit, tune=tune,
                       sigma_delta=sigma_delta, sigma_0=sigma_0)
    
    if mode == 'Uniform':
        beam = Beam(ring, )
    elif mode == 'Hybrid':
        pass
    elif mode == 'Low alpha/25':
        pass
    elif mode == 'Low alpha/25':
        pass
    elif mode == '8 bunches':
        pass
    elif mode == 'Single':
        pass
    else:
        raise ValueError("{} is not a correct operation mode.".format(mode))
    
    
    return ring